@@ -1,8 +1,9 @@
 leda_extract_from_local_df<-function(local_df,species_list,column_variables){
-    as.data.frame(species_list)->spec
+  as.data.frame(species_list)->spec
     TEMP<-as.data.frame(local_df[,column_variables])
     names(TEMP)<-column_variables
-    row.names(TEMP)<-row.names(local_df)
+  ##row.names(TEMP)<-row.names(local_df)
+  row.names(TEMP)<-local_df$Species
     spec<-merge(spec,TEMP,by.x="species_list",by.y=0,all.x=TRUE)
     DF<-spec[,column_variables,drop=FALSE]
     row.names(DF)<-spec$species_list
@@ -73,7 +74,7 @@ seed_simplify<-function(tp){
 #' #My_traits<-leda(species_list=c("Abies alba"))
 #' }
 leda<-function(species_list,TRAITS,rearranged){
-
+  
     res<-new("results")
     ## there are some problems with duplicate TNRS names for the LEDA
     ## database, thus I will use the original names
@@ -109,24 +110,24 @@ leda<-function(species_list,TRAITS,rearranged){
         
         if(!is.null(rearranged)){
             spec<-leda_extract_from_local_df(rearranged,species_list,column_variables)
-        }else{
-
-            leda_subset<-leda_lu[leda_lu$.id%in%tr_list,]
+        }## else{
+ 
+        ##     leda_subset<-leda_lu[leda_lu$.id%in%tr_list,]
             
-            spec<-as.data.frame(species_list)
-            row.names(spec)<-species_list
+        ##     spec<-as.data.frame(species_list)
+        ##     row.names(spec)<-species_list
 
-            for(trait in 1:nrow(leda_subset)){
-                    extract<-leda_subset[trait,]
-                    leda_temp<-leda_general(url=extract$V1 , skip_row=as.numeric(extract$V2), column=extract$V3, out_name=extract$V4,species=species_list)
-                    spec<-merge(spec,leda_temp,by.x=0,by.y=0,all.x=TRUE)
-                    row.names(spec)<-spec$Row.names
-                    names_of_column<-names(spec)[!(names(spec)%in%c("Row.names","species_list"))]
-                    spec<-as.data.frame(spec[,!(names(spec)%in%c("Row.names","species_list"))],row.names = species_list)
-                    names(spec)<-names_of_column
-            }
+        ##     for(trait in 1:nrow(leda_subset)){
+        ##             extract<-leda_subset[trait,]
+        ##             leda_temp<-leda_general(url=extract$V1 , skip_row=as.numeric(extract$V2), column=extract$V3, out_name=extract$V4,species=species_list)
+        ##             spec<-merge(spec,leda_temp,by.x=0,by.y=0,all.x=TRUE)
+        ##             row.names(spec)<-spec$Row.names
+        ##             names_of_column<-names(spec)[!(names(spec)%in%c("Row.names","species_list"))]
+        ##             spec<-as.data.frame(spec[,!(names(spec)%in%c("Row.names","species_list"))],row.names = species_list)
+        ##             names(spec)<-names_of_column
+        ##     }
 
-        }
+        ## }
         names(spec)<-mapvalues(names(spec),leda_lu$V4,leda_lu$.id,warn_missing = FALSE)
         res@results<-spec
     }
